# bots_airflow Docs

This directory is the start of the package-level documentation for `bots_airflow`.

Current pages:

- [Architecture and Release Vision](architecture.md)
- [Quickstart](quickstart.md)
- [850 Inbound Example](examples/850-inbound.md)
- [846 Outbound Example](examples/846-outbound.md)
- [Release and Documentation Workflow](release.md)

Planned documentation set:

- architecture and package boundaries
- quickstart examples
- translation API reference
- grammar authoring guide
- mapping authoring guide
- developer tools
- release and publishing guide
